@@ -1,3 +1,4 @@
+from __future__ import annotations
 from typing import Dict, Any, Union, Optional
 
 import pytorch_lightning as pl
@@ -41,7 +42,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         """Origin model to be trained
 
         Returns:
-            MetricModel: model to be trained
+            :class:`~quaterion_models.model.MetricModel`: model to be trained
         """
         return self._model
 
@@ -62,8 +63,11 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         before training as well as during the checkpoint loading.
 
         Returns:
-             Union[Encoder, Dict[str, Encoder]]: instance of encoder which will be assigned to
-             `quaterion_models.model.DEFAULT_ENCODER_KEY`, or mapping of names and encoders.
+            Union[:class:`~quaterion_models.encoders.encoder.Encoder`,
+            Dict[str, :class:`~quaterion_models.encoders.encoder.Encoder`]]:
+            instance of encoder which will be assigned to
+            :const:`~quaterion_models.model.DEFAULT_ENCODER_KEY`, or mapping of names and
+            encoders.
         """
         raise NotImplementedError()
 
@@ -74,7 +78,8 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         what kind of cache they should use.
 
         Returns:
-            Optional[CacheConfig]: cache configuration to be applied if provided, None otherwise
+            Optional[:class:`~quaterion.train.cache.cache_config.CacheConfig`]: cache configuration
+            to be applied if provided, None otherwise.
 
         Examples:
 
@@ -118,7 +123,8 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         Args:
             input_embedding_size: size of embeddings produced by encoders
         Returns:
-            EncoderHead: instance of EncoderHead to be added to the model
+            :class:`~quaterion_models.heads.encoder_head.EncoderHead`: head to be added on top of
+            a model
         """
         raise NotImplementedError()
 
@@ -149,7 +155,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         Args:
             batch: Output of DataLoader.
             batch_idx: Integer displaying index of this batch.
-            **kwargs: keyword arguments to be passed into `process_results`
+            **kwargs: keyword arguments to be passed into :meth:`~process_results`
 
         Returns:
             Tensor: computed loss value
@@ -167,7 +173,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         Args:
             batch: Output of DataLoader.
             batch_idx: Integer displaying index of this batch.
-            **kwargs: keyword arguments to be passed into `process_results`
+            **kwargs: keyword arguments to be passed into :meth:`~process_results`
         """
         stage = TrainStage.VALIDATION
         self._common_step(batch=batch, batch_idx=batch_idx, stage=stage, **kwargs)
@@ -180,7 +186,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         Args:
             batch: Output of DataLoader.
             batch_idx: Integer displaying index of this batch.
-            **kwargs: keyword arguments to be passed into `process_results`
+            **kwargs: keyword arguments to be passed into :meth:`~process_results`
         """
         stage = TrainStage.TEST
         self._common_step(batch=batch, batch_idx=batch_idx, stage=stage, **kwargs)
@@ -194,7 +200,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
             batch: Output of DataLoader.
             batch_idx: Integer displaying index of this batch.
             stage: current training stage: training, validation, etc.
-            **kwargs: keyword arguments to be passed into `process_results`
+            **kwargs: keyword arguments to be passed into :meth:`~process_results`
 
         Returns:
             Tensor: computed loss value
@@ -227,9 +233,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         train_dataloader: SimilarityDataLoader,
         val_dataloader: Optional[SimilarityDataLoader],
     ):
-        """
-        Fill cachable encoders with embeddings
-        """
+        """Fill cachable encoders with embeddings"""
         self._cache(
             trainer=trainer,
             encoders=self.model.encoders,
@@ -239,9 +243,7 @@ class TrainableModel(pl.LightningModule, CacheMixin):
         )
 
     def unwrap_cache(self):
-        """
-        Restore original encoders
-        """
+        """Restore original encoders"""
         self.model.encoders = self._unwrap_cache_encoders(self.model.encoders)
 
     def setup_dataloader(self, dataloader: SimilarityDataLoader):
